==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/scoug/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-F358886C-D3A9-48B7-9346-4348C9D33D3D"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Overview of Servicing Configurations",
                    "href":"overview-servicing-configurations.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Prerequisite",
                            "href":"prerequisite.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Branch Date Configurations",
                    "href":"branch-date-configurations.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Business Product Configuration",
                    "href":"business-product-configuration.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> About Business Product Configuration",
                            "href":"business-product-configuration1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> Create Business Product",
                            "href":"create-business-product.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> View Business Product",
                            "href":"view-business-product.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Business Process Configuration",
                    "href":"business-process-configuration1.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> About Business Process Configuration",
                            "href":"business-process-configuration.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Create Business Process",
                            "href":"create-business-process.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> View Business Process",
                            "href":"view-business-process.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Maintenance",
                    "href":"maintenance.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">5.1 </span> Bulletin Board Maintenance",
                            "href":"bulletin-board-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.1.1 </span> Create Bulletin",
                                    "href":"create-bulletin.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.1.2 </span> View Bulletin",
                                    "href":"view-bulletin.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.2 </span> Memo Maintenance",
                            "href":"memo-maintenance.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Servicing Configuration",
                    "href":"servicing-configurations.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6.1 </span> Create Service Preferences",
                            "href":"create-service-preferences.html"
                        },
                        {
                            "title":"<span class=\"secnum\">6.2 </span> View Service Preferences",
                            "href":"view-service-preferences.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> Error Codes and Messages",
                    "href":"appendix-error-codes-and-messages.html"
                },
                {
                    "title":"<span class=\"secnum\">B </span> Lifecycle Codes",
                    "href":"appendix-b-lifecycle-codes.html"
                },
                {
                    "title":"<span class=\"secnum\">C </span> Process Codes",
                    "href":"appendix-c-process-codes.html"
                },
                {
                    "title":"<span class=\"secnum\">D </span> Data Segment List",
                    "href":"appendix-d-data-segment-list.html"
                },
                {
                    "title":"<span class=\"secnum\">E </span> Functional Activity Codes",
                    "href":"appendix-e-functional-activity-codes.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/scoug/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-F358886C-D3A9-48B7-9346-4348C9D33D3D"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Overview of Servicing Configurations",
                    "href":"overview-servicing-configurations.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Prerequisite",
                            "href":"prerequisite.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Branch Date Configurations",
                    "href":"branch-date-configurations.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Business Product Configuration",
                    "href":"business-product-configuration.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> About Business Product Configuration",
                            "href":"business-product-configuration1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> Create Business Product",
                            "href":"create-business-product.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> View Business Product",
                            "href":"view-business-product.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Business Process Configuration",
                    "href":"business-process-configuration.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> About Business Process Configuration",
                            "href":"business-process-configuration1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Create Business Process",
                            "href":"create-business-process1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> View Business Process",
                            "href":"view-business-process.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Maintenance",
                    "href":"maintenance.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">5.1 </span> Bulletin Board Maintenance",
                            "href":"bulletin-board-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">5.1.1 </span> Create Bulletin",
                                    "href":"create-bulletin1.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">5.1.2 </span> View Bulletin",
                                    "href":"view-bulletin.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">5.2 </span> Memo Maintenance",
                            "href":"memo-maintenance1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">5.3 </span> Branch Servicing Auto Auth Setup",
                            "href":"branch-servicing-auto-auth-setup1.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Servicing Configuration",
                    "href":"servicing-configurations.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">6.1 </span> Create Service Preferences",
                            "href":"create-service-preferences.html"
                        },
                        {
                            "title":"<span class=\"secnum\">6.2 </span> View Service Preferences",
                            "href":"view-service-preferences1.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> Error Codes and Messages",
                    "href":"appendix---error-codes-messages.html"
                },
                {
                    "title":"<span class=\"secnum\">B </span> Lifecycle Codes",
                    "href":"appendix-b---lifecycle-codes.html"
                },
                {
                    "title":"<span class=\"secnum\">C </span> Process Codes",
                    "href":"appendix-c---process-codes.html"
                },
                {
                    "title":"<span class=\"secnum\">D </span> Data Segment List",
                    "href":"appendix-d---data-segment-list.html"
                },
                {
                    "title":"<span class=\"secnum\">E </span> Functional Activity Codes",
                    "href":"appendix-e---functional-activity-codes.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});
